  * Retrieve an icon loader HTML markup.
   *
   * @return {string} - HTML markup.
   */
  getIconLoader() {
    const icon = this.getAttribute('preloader-icon') || '';
    return `
			<i class="${this.escapeHTML(icon)} ${this.classes.preloader}"></i>
		`;
  }

  /**
   * Retrieve an image loader HTML markup.
   *
   * @return {string} - HTML markup.
   */
  getImageLoader() {
    const url = this.getAttribute('preloader-image-url') || '';
    return `
			<img class="${this.classes.preloader}" src="${this.escapeHTML(url)}" />
		`;
  }

  /**
   * Retrieve a custom loader HTML markup.
   *
   * @return {string} - HTML markup.
   */
  getAnimationLoader() {
    const type = this.getAttribute('preloader-animation-type');
    if (!type) {
      return '';
    }
    return `
			<e-preloader type="${type}"></e-preloader>
		`;
  }

  /**
   * Render the Page Transition element.
   *
   * @return {void}
   */
  render() {
    // Don't render when the Page Transition is disabled.
    if (this.hasAttribute('disabled')) {
      this.innerHTML = '';
      return;
    }
    const loaderType = this.getAttribute('preloader-type');
    switch (loaderType) {
      case 'icon':
        this.innerHTML = this.getIconLoader();
        break;
      case 'image':
        this.innerHTML = this.getImageLoader();
        break;
      case 'animation':
        this.innerHTML = this.getAnimationLoader();
        break;
      default:
        this.innerHTML = '';
        break;
    }
    this.innerHTML += this.getStyle();
  }

  /**
   * Get a CSS variable value from the current element's context.
   *
   * @param {string} variable - Variable name.
   * @param {string} prefix   - Variable prefix, defaults to `e-page-transition`.
   * @return {string} - CSS variable value.
   */
  getCssVar(variable) {
    let prefix = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'e-page-transition-';
    return window.getComputedStyle(this).getPropertyValue(`--${prefix}${variable}`);
  }

  /**
   * Get the animation duration as an integer in order to be used inside a `setTimeout`.
   *
   * Assumes that all of the timings are in `ms`.
   *
   * @return {number} - Animation duration.
   */
  getAnimationDuration() {
    return parseInt(this.getCssVar('animation-duration')) || 0;
  }

  /**
   * Get the preloader delay.
   *
   * Assumes that all of the timings are in `ms`.
   *
   * @return {number} - Preloader delay.
   */
  getPreloaderDelay() {
    return parseInt(this.getCssVar('delay', 'e-preloader-')) || 0;
  }

  /**
   * Start the animate sequence of the Page Transition (enter && exit).
   *
   * @return {Promise} - Animation sequence Promise.
   */
  animate() {
    // Don't animate if there is already an animation in progress.
    if (this.isAnimating) {
      return new Promise((resolve, reject) => {
        reject('Animation is already in progress.');
      });
    }
    this.isAnimating = true;

    // Delay the exit animation so the user will be able to see the loader for a second.
    const delay = this.getPreloaderDelay() + 1500;
    this.classList.remove(this.classes.entered);
    return new Promise(resolve => {
      // Defer to make sure that the `entered` class is fully removed before animating.
      // Return a Promise for animations chaining.
      setTimeout(() => {
        this.animateState('exiting', delay).then(() => {
          this.animateState('entering').then(() => {
            this.classList.add(this.classes.entered);
            this.isAnimating = false;
            resolve();
          });
        });
      });
    });
  }

  /**
   * Animate a state of the Page Transition (enter || exit).
   *
   * @param {('entering'|'exiting')} state - The state name to animate.
   * @param {number}                 delay - Delay (in ms) before resolving the Promise.
   * @return {Promise} - Animation sequence Promise.
   */
  animateState(state) {
    let delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    const className = this.classes?.[state];
    if (!className) {
      return new Promise((resolve, reject) => {
        reject(state);
      });
    }

    // Remove and add the class again to force the animation, since it's using `animation-fill-mode: forwards`.
    this.classList.remove(className);
    this.classList.add(className);

    // Return a Promise for animations chaining.
    const animationDuration = this.getAnimationDuration();
    return new Promise(resolve => {
      setTimeout(() => {
        this.classList.remove(className);
        resolve(state);
      }, animationDuration + delay);
    });
  }

  /**
   * Listen to attribute changes and re-render the element.
   *
   * @return {void}
   */
  attributeChangedCallback() {
    this.render();
  }

  /**
   * Render the element when attached to the document.
   *
   * @return {void}
   */
  connectedCallback() {
    this.render();
  }
}
exports.PageTransition = PageTransition;
var _default = PageTransition;
exports["default"] = _default;

/***/ }),

/***/ "../modules/page-transitions/assets/js/frontend/components/preloader/preloader.js":
/*!****************************************************************************************!*\
  !*** ../modules/page-transitions/assets/js/frontend/components/preloader/preloader.js ***!
  \****************************************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "../node_modules/@babel/runtime/helpers/interopRequireDefault.js");
Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = exports.Preloader = void 0;
var _preloaderComponent = _interopRequireDefault(__webpack_require__(/*! ./preloader.component.scss */ "../modules/page-transitions/assets/js/frontend/components/preloader/preloader.component.scss"));
class Preloader extends HTMLElement {
  /**
   * A list of attributes to observe for changes.
   *
   * @return {string[]} - Attributes to observe.
   */
  static get observedAttributes() {
    return ['type'];
  }

  /**
   * Listen to attribute changes and re-render the element.
   *
   * @return {void}
   */
  attributeChangedCallback() {
    this.render();
  }

  /**
   * Get the Preloader CSS.
   *
   * @return {string} - CSS code.
   */
  getStyle() {
    return `<style>${_preloaderComponent.default.toString()}</style>`;
  }

  /**
   * Render the Preloader element.
   *
   * @return {void}
   */
  render() {
    const type = this.getAttribute('type'),
      dotsTypes = ['bouncing-dots', 'pulsing-dots'];
    this.innerHTML = '';
    if (!type) {
      return;
    }
    if (dotsTypes.includes(type)) {
      this.innerHTML += `
				<i></i>
				<i></i>
				<i></i>
				<i></i>
			`;
    }
    this.innerHTML += this.getStyle();
  }

  /**
   * Render the element when attached to the document.
   *
   * @return {void}
   */
  connectedCallback() {
    this.render();
  }
}
exports.Preloader = Preloader;
var _default = Preloader;
exports["default"] = _default;

/***/ }),

/***/ "../modules/page-transitions/assets/js/frontend/components/page-transition/page-transition.component.scss":
/*!****************************************************************************************************************!*\
  !*** ../modules/page-transitions/assets/js/frontend/components/page-transition/page-transition.component.scss ***!
  \****************************************************************************************************************/
/***/ ((module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../../../../../node_modules/css-loader/dist/runtime/api.js */ "../node_modules/css-loader/dist/runtime/api.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_0__);
// Imports

var ___CSS_LOADER_EXPORT___ = _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_0___default()(function(i){return i[1]});
// Module
___CSS_LOADER_EXPORT___.push([module.id, "e-page-transition{--preloader-fade-duration: .5s;--preloader-delay: calc( var( --e-page-transition-animation-duration, 0s ) + var( --e-preloader-delay, 0s ) );--page-transition-delay: var( --preloader-fade-duration );position:fixed;inset:0;display:grid;place-items:center;z-index:10000;background:#fff;animation-fill-mode:both;animation-duration:var(--e-page-transition-animation-duration)}e-page-transition[disabled]{display:none}e-page-transition e-preloader,e-page-transition .e-page-transition--preloader{opacity:0}e-page-transition .e-page-transition--preloader{position:absolute;font-size:var(--e-preloader-size);color:var(--e-preloader-color);fill:var(--e-preloader-color);width:var(--e-preloader-width);max-width:var(--e-preloader-max-width);transform:rotate(var(--e-preloader-rotate, 0deg));animation-name:var(--e-preloader-animation);animation-duration:var(--e-preloader-animation-duration, 1000ms);animation-iteration-count:infinite;animation-timing-function:linear}e-page-transition svg.e-page-transition--preloader{width:var(--e-preloader-size)}.e-page-transition--entering{animation-name:var(--e-page-transition-entrance-animation);animation-delay:var(--preloader-fade-duration, 0s)}.e-page-transition--entering e-preloader,.e-page-transition--entering .e-page-transition--preloader{animation:var(--e-preloader-animation, none) var(--e-preloader-animation-duration, 0s) linear infinite,e-page-transition-fade-out var(--preloader-fade-duration) both;transition:none}.e-page-transition--exiting{animation-name:var(--e-page-transition-exit-animation)}.e-page-transition--exiting e-preloader,.e-page-transition--exiting .e-page-transition--preloader{opacity:var(--e-preloader-opacity, 1);transition:var(--preloader-fade-duration) all;transition-delay:var(--preloader-delay, 0s)}.e-page-transition--entered:not(.e-page-transition--preview){display:none}.e-page-transition--preview{animation-fill-mode:initial}.e-page-transition--preview.e-page-transition--entered e-preloader,.e-page-transition--preview.e-page-transition--entered .e-page-transition--preloader{opacity:var(--e-preloader-opacity, 1)}@media(prefers-reduced-motion: reduce){e-page-transition{display:none}}@keyframes e-page-transition-fade-in{from{opacity:0}to{opacity:1}}@keyframes e-page-transition-fade-in-down{from{opacity:0;transform:translate3d(0, -100%, 0)}to{opacity:1;transform:none}}@keyframes e-page-transition-fade-in-left{from{opacity:0;transform:translate3d(-100%, 0, 0)}to{opacity:1;transform:none}}@keyframes e-page-transition-fade-in-right{from{opacity:0;transform:translate3d(100%, 0, 0)}to{opacity:1;transform:none}}@keyframes e-page-transition-fade-in-up{from{opacity:0;transform:translate3d(0, 100%, 0)}to{opacity:1;transform:none}}@keyframes e-page-transition-zoom-in{from{opacity:0;transform:scale3d(0.3, 0.3, 0.3)}50%{opacity:1}}@keyframes e-page-transition-slide-in-down{from{transform:translate3d(0, -100%, 0);visibility:visible}to{transform:translate3d(0, 0, 0)}}@keyframes e-page-transition-slide-in-left{from{transform:translate3d(-100%, 0, 0);visibility:visible}to{transform:translate3d(0, 0, 0)}}@keyframes e-page-transition-slide-in-right{from{transform:translate3d(100%, 0, 0);visibility:visible}to{transform:translate3d(0, 0, 0)}}@keyframes e-page-transition-slide-in-up{from{transform:translate3d(0, 100%, 0);visibility:visible}to{transform:translate3d(0, 0, 0)}}@keyframes e-page-transition-fade-out{from{opacity:1}to{opacity:0}}@keyframes e-page-transition-fade-out-up{from{opacity:1;transform:none}to{opacity:0;transform:translate3d(0, -100%, 0)}}@keyframes e-page-transition-fade-out-left{from{opacity:1;transform:none}to{opacity:0;transform:translate3d(-100%, 0, 0)}}@keyframes e-page-transition-fade-out-right{from{opacity:1;transform:none}to{opacity:0;transform:translate3d(100%, 0, 0)}}@keyframes e-page-transition-fade-out-down{from{opacity:1;transform:none}to{opacity:0;transform:translate3d(0, 100%, 0)}}@keyframes e-page-transition-slide-out-up{from{transform:translate3d(0, 0, 0)}to{transform:translate3d(0, -100%, 0);visibility:visible}}@keyframes e-page-transition-slide-out-left{from{transform:translate3d(0, 0, 0)}to{transform:translate3d(-100%, 0, 0);visibility:visible}}@keyframes e-page-transition-slide-out-right{from{transform:translate3d(0, 0, 0)}to{transform:translate3d(100%, 0, 0);visibility:visible}}@keyframes e-page-transition-slide-out-down{from{transform:translate3d(0, 0, 0)}to{transform:translate3d(0, 100%, 0);visibility:visible}}@keyframes e-page-transition-zoom-out{from{opacity:1}50%{opacity:0;transform:scale3d(0.3, 0.3, 0.3)}}", ""]);
// Exports
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (___CSS_LOADER_EXPORT___);


/***/ }),

/***/ "../modules/page-transitions/assets/js/frontend/components/preloader/preloader.component.scss":
/*!****************************************************************************************************!*\
  !*** ../modules/page-transitions/assets/js/fronte